.. _ReferencePage:

=========
Reference
=========

.. sectnum:: :start: 2


See :ref:`UsagePage` for how to use these functions for common map manipulation tasks.

enmap - General map manipulation
--------------------------------

.. automodule:: pixell.enmap
   :members:
   :undoc-members:

fft - Fourier transforms
------------------------

.. automodule:: pixell.fft
   :members:
   :undoc-members:

curvedsky - Curved-sky harmonic transforms
------------------------------------------

.. automodule:: pixell.curvedsky
   :members:
   :undoc-members:

utils - General utilities
-------------------------

.. automodule:: pixell.utils
   :members:
   :undoc-members:

reproject - Map reprojection
----------------------------
.. automodule:: pixell.reproject
   :members:
   :undoc-members:

resample - Map resampling
-------------------------

.. automodule:: pixell.resample
   :members:
   :undoc-members:

lensing - Lensing
-----------------

.. automodule:: pixell.lensing
   :members:
   :undoc-members:

pointsrcs - Point Sources
-------------------------

.. automodule:: pixell.pointsrcs
   :members:
   :undoc-members:

interpol - Interpolation
------------------------

.. automodule:: pixell.interpol
   :members:
   :undoc-members:

coordinates - Coordinate Transformation
---------------------------------------

.. automodule:: pixell.coordinates
   :members:
   :undoc-members:

wcsutils - World Coordinate Sytem utilities
-------------------------------------------

.. automodule:: pixell.wcsutils
   :members:
   :undoc-members:

powspec - CMB power spectra utilities
-------------------------------------

.. automodule:: pixell.powspec
   :members:
   :undoc-members:

enplot - Producing plots from ndmaps
------------------------------------

.. automodule:: pixell.enplot
   :members:
   :undoc-members:

tilemap - Tiled maps where only some tiles are stored
-----------------------------------------------------

.. automodule:: pixell.tilemap
   :members:
   :undoc-members:
